import Action from "./Action";
/**
 * Submit action
 *
 * @since 1.0.0
 */
export default class ActionSubmit extends Action {
    actionData;
    /**
    * Constuctor.
    *
    * @param form Form object.
    * @param actionData Action data.
    *
    * @since 1.0.0
    */
    constructor(form, actionData) {
        super(form);
        this.actionData = actionData;
    }
    /**
     * Run action.
     *
     * @since 1.0.0
     */
    execute() {
        this.fetch(this.actionData.endpoint, this.form.fieldsets.getData()).then((response) => {
            this.form.alert.success(this.actionData.success);
        });
    }
    /**
     *
     * @param url
     * @param data
     * @returns
     */
    fetch(url = '', data = {}) {
        const response = fetch(url, {
            method: this.actionData.method,
            mode: 'cors',
            cache: 'no-cache',
            credentials: 'same-origin',
            headers: {
                'Content-Type': 'application/json'
            },
            redirect: 'follow',
            referrerPolicy: 'no-referrer',
            body: JSON.stringify(data)
        });
        return response;
    }
}
