import type HasFieldData from '../Interfaces/HasFieldData';
import type HasChoicesData from '../Interfaces/HasChoicesData';
import CSSClasses from '../Helpers/CSSClasses';
import type HasValidationData from '../Interfaces/HasValidationData';
import type HasReplacementData from '../Interfaces/HasReplacementData';
import type HasConditionData from '../Interfaces/HasConditionData';
import ValueCallback from '../Helpers/ValueCallback';
/**
 * Field class.
 *
 * @since 1.0.0
 */
export default abstract class Field {
    readonly id: string;
    readonly type: string;
    readonly label: string;
    readonly placeholder: string;
    readonly options: HasChoicesData[];
    readonly prefix: string;
    readonly suffix: string;
    readonly help: string;
    readonly classes: CSSClasses;
    readonly labelClasses: CSSClasses;
    readonly inputClasses: CSSClasses;
    readonly size: number;
    readonly conditions: HasConditionData[];
    readonly validations: HasValidationData[];
    readonly replacements: HasReplacementData[];
    readonly valueDefault: any;
    readonly valueCallback: ValueCallback;
    protected formValues: {};
    protected errors: string[];
    protected isValidated: boolean;
    /**
     * Initializing field.
     *
     * @param fieldData  Field data.
     * @param formValues Form values.
     *
     * @since 1.0.0
     */
    constructor(fieldData: HasFieldData, formValues: {});
    /**
     * Updating field assets
     *
     * @since 1.0.0
     */
    updateAssets(): void;
    /**
     * Replace a value by field replacements.
     *
     * @param value Value to be replaced.
     *
     * @returns Replaced value.
     *
     * @since 1.0.0
     */
    protected replace(value: any): any;
    /**
     * Checks if conditions for displaying field are met.
     *
     * @returns True if conditions are met, false otherwise.
     *
     * @since 1.0.0
     */
    protected conditionsFulfilled(): boolean;
    /**
     * Get errors of the field.
     *
     * @returns Erros of the field.
     *
     * @since 1.0.0
     */
    getErrors(): string[];
    /**
     * Is field visible.
     *
     * @returns True if field is visible, false otherwise.
     *
     * @since 1.0.0
     */
    isVisible(): boolean;
    /**
     * Validate field.
     *
     * @returns True if field is valid, false otherwise.
     *
     * @since 1.0.0
     */
    abstract validate(): boolean;
}
