import Text from '../../Components/Fields/Input/Text.svelte';
import Textarea from '../../Components/Fields/Input/Textarea.svelte';
import Range from '../../Components/Fields/Input/Range.svelte';
import Checkbox from '../../Components/Fields/Input/Checkbox.svelte';
import Select from '../../Components/Fields/Input/Select.svelte';
import Radio from '../../Components/Fields/Input/Radio.svelte';
/**
 * Navigation class.
 *
 * @since 1.0.0
 */
export default class Registration {
    elements = [];
    /**
     * Constructor.
     *
     * @since 1.0.0
     */
    constructor() {
        this.registerDefaults();
    }
    /**
     * Add element to register
     *
     * @param name  Help data.
     *
     * @since 1.0.0
     */
    addElement(name, input) {
        this.elements[name] = input;
    }
    /**
     * Get a specific element.
     *
     * @param name Element name.
     *
     * @returns Svelte component element object.
     *
     * @since 1.0.0
     */
    getElement(name) {
        if (this.elements[name] === undefined) {
            console.error('Element type not found: ' + name);
            return;
        }
        return this.elements[name];
    }
    /**
     * Register standard Elements.
     *
     * @since 1.0.0
     */
    registerDefaults() {
        this.addElement('text', Text);
        this.addElement('textarea', Textarea);
        this.addElement('range', Range);
        this.addElement('checkbox', Checkbox);
        this.addElement('select', Select);
        this.addElement('radio', Radio);
    }
}
