import type HasFormData from '../Interfaces/HasFormData';
import CSSClasses from '../Helpers/CSSClasses';
import Fieldset from './Fieldset';
import type HasNavigationData from '../Interfaces/HasNavigationData';
import Events from '../Actions/Events';
import type Trigger from '../../Types/Trigger';
/**
 * Class Form.
 *
 * @since 1.0.0
 */
export default class Form {
    readonly id: string;
    readonly fieldsets: Fieldset[];
    readonly classes: CSSClasses;
    private formValues;
    private currentFieldsetId;
    readonly navigationData: HasNavigationData;
    readonly events: Events;
    /**
     * Initializing form data.
     *
     * @param formData Formdata from JSON file.
     *
     * @since 1.0.0
     */
    constructor(formData: HasFormData, formValues?: {});
    /**
     * Execute triggers.
     *
     * @return boolean True if all events were executed successfully.
     *
     * @since 1.0.0
     */
    executeEvents(trigger: Trigger): boolean;
    /**
     * Execute callbacks.
     *
     * @param trigger Trigger to execute.
     *
     * @since 1.0.0
     */
    executeFieldCallbacks(trigger: Trigger): void;
    /**
     * Set current fieldset.
     *
     * @param fieldsetId Id of fieldset.
     *
     * @since 1.0.0
     */
    setCurrentFieldset(fieldsetId: string): void;
    /**
     * Check if fieldset exists.
     *
     * @param fieldsetId Fieldset id.
     *
     * @returns boolean True if fieldset exists, false if not.
     *
     * @since 1.0.0
     */
    fieldsetExists(fieldsetId: string): boolean;
    /**
     * Get current fieldset id.
     *
     * @returns string Current fieldset id.
     *
     * @since 1.0.0
     */
    getCurrentFieldsetId(): string;
    /**
     * Get current fieldset.
     *
     * @returns {Fieldset} Fieldset object.
     *
     * @since 1.0.0
     */
    getCurrentFieldset(): Fieldset;
    /**
     * Get value by field id.
     *
     * @param fieldId Field id.
     *
     * @returns {any} Value of field.
     *
     * @since 1.0.0
     */
    getValue(fieldId: string): any;
    /**
     * Set value by field id.
     *
     * @param fieldId Field id.
     * @param value Value to set.
     *
     * @since 1.0.0
     */
    setValue(fieldId: string, value: any): void;
    /**
     * Get form values.
     *
     * @returns [] Form values.
     *
     * @since 1.0.0
     */
    getValues(): {};
    /**
     * Has navigation data (CSS etc).
     *
     * @returns Boolean True if form has navigation data, false if not.
     *
     * @since 1.0.0
     */
    hasNavigationData(): boolean;
}
