import CSSClasses from "../Helpers/CSSClasses";
import type Fieldset from "../Form/Fieldset";
import type Form from "./Form";
/**
 * Navigation class.
 *
 * @since 1.0.0
 */
export default class Navigation {
    readonly fieldsets: Fieldset[];
    private form;
    private currentFieldset;
    readonly classes: CSSClasses;
    readonly buttonsClasses: CSSClasses;
    /**
     * Initializing navigation.
     *
     * @param form  Form object.
     * @param navigationData Navigation data.
     *
     * @since 1.0.0
     */
    constructor(form: Form);
    /**
     * Get current fieldset.
     *
     * @return Current fieldset.
     *
     * @since 1.0.0
     */
    getCurrentFieldset(): Fieldset;
    /**
     * Set previous fieldset.
     *
     * @return Navigation object.
     *
     * @since 1.0.0
     */
    prev(): void;
    /**
     * Set next fieldset.
     *
     * @return Navigation object.
     *
     * @since 1.0.0
     */
    next(): void;
    /**
     * Is there a previous fieldset?
     *
     * @return True if there is a previous fieldset, false if not.
     *
     * @since 1.0.0
     */
    hasPrev(): boolean;
    /**
     * Is there a next fieldset?
     *
     * @return True if there is a previous fieldset, false if not.
     *
     * @since 1.0.0
     */
    hasNext(): boolean;
    /**
     * Set current fieldset.
     *
     * @param fieldsetId Id of fieldset.
     *
     * @since 1.0.0
     */
    private _setCurrentFieldset;
}
