/**
 * Button class.
 *
 * @since 1.0.0
 */
export default class Button {
    buttonData;
    /**
     * Constructor.
     *
     * @param buttonData Button data.
     *
     * @since 1.0.0
     */
    constructor(buttonData) {
        this.buttonData = buttonData;
    }
    /**
     * Get button label.
     *
     * @returns Label of button.
     *
     * @since 1.0.0
     */
    getLabel() {
        return this.buttonData.label;
    }
    /**
     * Get method name of callback.
     *
     * @returns
     *
     * @since 1.0.0
     */
    getMethod() {
        return this.buttonData.callback.method;
    }
    /**
     * Fires button callback.
     *
     * @since 1.0.0
     */
    click(dismiss) {
        const methodName = this.buttonData.callback.method;
        const params = this.buttonData.callback.args;
        if (methodName === "dismiss") {
            dismiss();
        }
        else {
            const method = window[methodName];
            method.apply(window, params !== undefined ? params : []);
        }
    }
}
