/**
 * CSSClasses.
 *
 * @since 1.0.0
 */
export default class CSSClasses {
    cssClasses;
    /**
     * Constructor.
     *
     * @param cssClasses Array of CSS classes.
     *
     * @since 1.0.0
     */
    constructor(cssClasses = []) {
        this.cssClasses = cssClasses;
    }
    /**
     * Get CSS classes.
     *
     * @returns CSS classes array.
     *
     * @since 1.0.0
     */
    get() {
        return this.cssClasses;
    }
    /**
     * Get classes string for HTML parameter.
     *
     * @returns CSS classes in a string.
     *
     * @since 1.0.0
     */
    toString() {
        if (Array.isArray(this.cssClasses)) {
            return this.cssClasses.join(' ');
        }
        console.error("CSS Classes have to be array. Current value:", this.cssClasses);
    }
    /**
     * Add CSS class.
     *
     * @param name Name of CSS class to add.
     *
     * @since 1.0.0
     */
    add(name) {
        this.cssClasses.push(name);
    }
    /**
     * Remove CSS class.
     *
     * @param name Name of CSS class to remove.
     *
     * @since 1.0.0
     */
    remove(name) {
        this.cssClasses = this.cssClasses.filter(className => className !== name);
    }
}
